object code blow up by optimization
Christian Maeder
maeder at tzi.de
Thu Jan 26 14:03:25 EST 2006
Sorry, I forgot to save my changes. The numbers are much better with infixr:
Linking ...
real 5m30.666s
user 4m56.950s
sys 0m9.262s
maeder at turing:~/haskell/examples> ll a.out HasCASL/PrintLe.o
-rwxr-xr-x 1 maeder wimi 4812378 2006-01-26 20:01 a.out
-rw-r--r-- 1 maeder wimi 139828 2006-01-26 19:58 HasCASL/PrintLe.o
Christian Maeder wrote:
> P.S. I've changed infixl to infixr
> infixr 6 <>
> infixr 6 <+>
> infixr 5 $$, $+$
>
> Not much difference in code size but a bit faster compared to the
> numbers I've posted before:
>
> http://hackage.haskell.org/trac/ghc/ticket/490
>
> Linking ...
>
> real 7m37.899s
> user 6m45.562s
> sys 0m11.161s
>
> maeder at turing:~/haskell/examples> ll a.out HasCASL/PrintLe.o
> -rwxr-xr-x 1 maeder wimi 6468124 2006-01-26 19:48 a.out
> -rw-r--r-- 1 maeder wimi 2010772 2006-01-26 19:46 HasCASL/PrintLe.o
More information about the Glasgow-haskell-bugs
mailing list